#
# spec file for package python-coverage
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-coverage
Version:        3.5.3
Release:        1.1
Url:            http://nedbatchelder.com/code/coverage/%{version}
Summary:        Code coverage measurement for Python
License:        BSD-2-Clause and (GPL-2.0+ or MIT)
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/c/coverage/coverage-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-distribute
BuildRequires:  python-xml
Requires:       python-distribute
Requires:       python-xml
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif

%description
Coverage.py measures code coverage, typically during test execution. It uses
the code analysis tools and tracing hooks provided in the Python standard
library to determine which lines are executable, and which have been executed.

%prep
%setup -q -n coverage-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS.txt CHANGES.txt README.txt
%{_bindir}/coverage
%{python_sitearch}/coverage/
%{python_sitearch}/coverage-%{version}-py%{py_ver}.egg-info

%changelog
* Tue Nov 20 2012 saschpe@suse.de
- Update to version 3.5.3:
  + Line numbers in the HTML report line up better with the source lines, fixing
    issue 197
  + When specifying a directory as the source= option, the directory itself no
    longer needs to have a __init__.py file, though its subdirectories do, to
    be considered as source files.
  + Files encoded as UTF-8 with a BOM are now properly handled, fixing
    issue 179_.
  + Fixed more cases of non-Python files being reported as Python source, and
    then not being able to parse them as Python.  Closes issue 82 (again).
  + Fixed memory leaks under Python 3, thanks, Brett Cannon. Closes issue 147_.
  + Optimized .pyo files may not have been handled correctly, issue 195_.
  + Certain unusually named file paths could have been mangled during reporting,
    issue 194_.
  + Try to do a better job of the impossible task of detecting when we can't
    build the C extension, fixing issue 183_.
  + Testing is now done with tox
- Changes from version 3.5.2:
  + No changes since 3.5.2.b1
- Changes from version 3.5.2b1
  + The HTML report has slightly tweaked controls: the buttons at the top of
    the page are color-coded to the source lines they affect.
  + Custom CSS can be applied to the HTML report by specifying a CSS file as
    the extra_css configuration value in the [html] section.
  + Source files with custom encodings declared in a comment at the top are now
    properly handled during reporting on Python 2.  Python 3 always handled them
    properly.  This fixes issue 157_.
  + Backup files left behind by editors are no longer collected by the source=
    option, fixing issue 168_.
  + If a file doesn't parse properly as Python, we don't report it as an error
    if the filename seems like maybe it wasn't meant to be Python.  This is a
    pragmatic fix for issue 82_.
  + The -m switch on coverage report, which includes missing line numbers
    in the summary report, can now be specifed as show_missing in the
    config file.  Closes issue 173_.
  + When running a module with coverage run -m <modulename>, certain details
    of the execution environment weren't the same as for
    python -m <modulename>.  This had the unfortunate side-effect of making
    coverage run -m unittest discover not work if you had tests in a
    directory named "test".  This fixes issue 155_.
  + Now the exit status of your product code is properly used as the process
    status when running python -m coverage run ....  Thanks, JT Olds.
  + When installing into pypy, we no longer attempt (and fail) to compile
    the C tracer function, closing issue 166_.
* Thu May 24 2012 cfarrell@suse.com
- license update: BSD-2-Clause and (GPL-2.0+ or MIT)
  __init__.py is the only file with a definitive license statement
  (BSD-2-Clause). Also, package contains jquery components (GPL-2.0+ or
  MIT)
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
- minor spec improvement (files section)
* Sat Mar 10 2012 saschpe@gmx.de
- Simplify macro usage
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 3.5.1:
  * The [paths] feature unfortunately didn't work in real world situations
    where you wanted to, you know, report on the combined data.  Now all paths
    stored in the combined file are canonicalized properly.
* Tue Sep 27 2011 saschpe@suse.de
- Add python-distribute runtime requirement
* Thu Sep  8 2011 saschpe@suse.de
- Update to version 3.5.1b1:
  * for-else constructs are understood better, and don't cause erroneous partial
    branch warnings.  Fixes issue 122.
  * Branch coverage for with statements is improved, fixing issue 128.
  * The number of partial branches reported on the HTML summary page was
    different than the number reported on the individual file pages.  This is
    now fixed.
  * An explicit include directive to measure files in the Python installation
    wouldn't work because of the standard library exclusion.  Now the include
    directive takes precendence, and the files will be measured.  Fixes
    issue 138.
  * The HTML report now handles Unicode characters in Python source files
    properly. This fixes issue 124 and issue 144. Thanks, Devin
    Jeanpierre.
  * In order to help the core developers measure the test coverage of the
    standard library, Brandon Rhodes devised an aggressive hack to trick Python
    into running some coverage code before anything else in the process.
    See the coverage/fullcoverage directory if you are interested.
  ...see CHANGES.txt for more
- Spec file cleanup:
  * Use python-distribute instead of python-setuptools
  * Changed license to BSD-3-Clause (SPDX style)
* Fri May  6 2011 saschpe@suse.de
- Update to version 3.4:
  + The XML report is now sorted by package name, fixing issue 88.
  + Programs that exited with sys.exit() with no argument weren't handled
    properly, producing a coverage.py stack trace.  That is now fixed.
- Changes from version 3.3.1:
  + Using parallel=True in .coveragerc file prevented reporting, but now does
    not, fixing issue 49.
  + When running your code with "coverage run", if you call sys.exit(),
    coverage.py will exit with that status code, fixing issue 50.
- Added documentation (AUTHORS.txt, CHANGES.txt and README.txt)
- Addded changes file
* Sat Aug 22 2009 cfarrell1980@gmail.com
- Require setuptools
* Thu May 28 2009 cfarrell1980@gmail.com
- Initial import
